@@ -27,6 +27,10 @@ class ZencachedApplication(SimpleOrpcApplication):
         })
         return config
 
+    def main(self):
+        from gevent import monkey
+        monkey.patch_all()
+        return super().main()
 
 zencached_application = ZencachedApplication().get_controller()
 
